# FILE: PlotCompare.gp
# COPYRIGHT (c): Symmetric Research, 2011-2016
#
# This GnuPlot file plots data from a USBxCH board twice.  The first
# plot uses the raw data, while the second uses the interpolated data.
#
# To run, call PlotCompare.bat or go down to the directory with Before.fw4
# and After.fw4, start GnuPlot and use ...   load '..\PlotCompare.gp'
#
# The interpolation is done with a straight line equation.  The output points
# are also aligned on the second.  Because the sample interval has been 
# changed, the data must be plotted against time and not against sample number.
#
# Peak amplitudes will be cut off since a straight line interpolator can only
# create points which lie between (not above) existing points.  Both the initial
# input sampling rate and the final output sampling rate should be high enough
# to capture all the frequencies of interest for your application.
#



# REMOVE ANY PREVIOUS DEFAULT SETTINGS
#
#

reset




# DEFINE SOME HANDY CONSTANTS RELATED TO THE DATA FILE
#
#

DataFileBef = "Before.fw4"
DataFileAft = "After.fw4"


# Fill in the start time appropriate for the current data files.
#
#
StartTime = 1466104593


# Comment in the column positions for the USBxCH appropriate for YOUR setup.
# Don't forget to change the $15 or $19 in the plot command below too.

ColSample = 1          # sample number  is in column 1
ColData   = 2          # channel 0 data is in column 2

#ColTime = 19          # For USB8CH time in seconds is in column 19
ColTime  = 15          # For USB4CH time in seconds is in column 15




# DEFINE LABEL FOR AXES, PLOT AND KEY AND CONTROL RANGE OF AXES
#
# Offset on ylabel moves it 5 characters to the left (-5 in x direction,
# and 0 in the y direction) so it doesn't run into the count values.
#
#

set title  "USBxCH Acquired vs Interpolated Comparison"  font "Helvetica Bold,16"

set xlabel "Time in Seconds"    font "Helvetica Bold,14"
set ylabel "Data Counts"        font "Helvetica Bold,14"  offset -5,0

set xtics nomirror              font "Helvetica Bold,14"
set ytics nomirror              font "Helvetica Bold,14"

KeyTitleBef = "Data Acquired at 1302Hz (BEFORE interpolation)"
KeyTitleAft = "Data Interpolated to 215Hz (AFTER interpolation)"





# SET THE DATA PLOTTING STYLE
#
# The first set style says plot data with points connected by lines.  The
# next set styles defines linestyle 1 and 2 that can be referenced later by
# the plot command.  The first style has black lines connecting small open
# circle points, while the second has red lines connecting large solid diamond 
# points.
#

set style data linespoint
set style line 1 linetype -1 linewidth 1 pointtype  6 pointsize 1
set style line 2 linetype  1 linewidth 1 pointtype 13 pointsize 1



# NOW DO THE PLOT
#
#

# To reproduce the PDF, use these ranges for the sample data:
#
set xrange [3.42:3.57]
set yrange [-450000:450000]


plot DataFileBef using ($15-StartTime):ColData linestyle 1 title KeyTitleBef, \
     DataFileAft using ($15-StartTime):ColData linestyle 2 title KeyTitleAft


pause -1 "Press enter to exit GnuPlot"


# CLEAN UP SETTINGS
#
#

reset
