﻿' FILE: VbDisplayForm.vb
' COPYRIGHT: (c), Symmetric Research, 2015-2017
'
' Source code for the actions of the USBxCH VbDisplay form which reads BIN
' data from a SrPipe and displays in in a Visual Basic GUI window.
'

Imports Microsoft.VisualBasic
Imports System
Imports System.Drawing
Imports System.Windows.Forms

Public Class VbDisplayForm


    ' Constants and global variables:
    ' The ProgramName MUST be the name of the executable eg VbDisplay

    Private Const ProgramName As String = "VbDisplay"
    Private hPipeInput As Integer


    
    '---------------------------------------------------------------------------
    ' ROUTINE: New
    ' PURPOSE: Default code to initialize the form components.
    '---------------------------------------------------------------------------
    Public Sub New()

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.

        StartDisplay()

    End Sub

    '---------------------------------------------------------------------------
    ' ROUTINE: Finalize
    ' PURPOSE: Default code to perform any final actions.
    '---------------------------------------------------------------------------
    Protected Overrides Sub Finalize()
        MyBase.Finalize()
    End Sub

    '---------------------------------------------------------------------------
    ' ROUTINE: StartDisplay
    ' PURPOSE: When starting the display, open the pipe and start the timer
    '          for checking for new data.
    '---------------------------------------------------------------------------
    Private Sub StartDisplay()

        Dim PipeName As String

        
        ' Open report file.

        VbCustomReportOpen( ProgramName )
        VbCustomReportPrint( ProgramName & " starting" &  vbCrLf )


        ' Open the named pipe.

        PipeName = REQUIRED_PIPE_PREFIX & ProgramName

        hPipeInput = VbCustomOpenInputPipe(PipeName)

        If hPipeInput = INVALID_HANDLE_VALUE Then
            VbCustomReportPrint( "Pipe Open Error number " & Err.LastDllError & vbCrLf )
            MessageBox.Show("Pipe Open Error number " & Err.LastDllError)
            Exit Sub
        End If


        ' Start the timer.

        Timer1.Enabled = True
        Timer1.Start()

    End Sub

    '---------------------------------------------------------------------------
    ' ROUTINE: StopBtn_Click
    ' PURPOSE: When the Stop button is clicked, stop the timer, close the
    '          pipe and exit the application.
    '---------------------------------------------------------------------------
    Private Sub StopBtn_Click(sender As Object, e As System.EventArgs) Handles StopBtn.Click

        ' Stop timer, close pipe, and exit.

        Timer1.Stop()

        VbCustomCloseInputPipe(hPipeInput)

        VbCustomReportPrint( ProgramName & " ending" &  vbCrLf )
        
        Application.Exit()

    End Sub

    '---------------------------------------------------------------------------
    ' ROUTINE: Timer1_Tick
    ' PURPOSE: Each time the timer tick occurs, temporarily stop the timer, read
    '          the next BIN data point from the pipe, update the display values,
    '          and restart the timer.
    '---------------------------------------------------------------------------
    Private Sub Timer1_Tick(sender As System.Object, e As System.EventArgs) Handles Timer1.Tick

        Dim res, Ready As Integer
        Dim BinData As BinLayout

        ' Temporarily stop timer until we are done processing the current tick.

        Timer1.Stop()


        ' Peek at the named pipe and check for error and for ready data.

        res = VbCustomPeekInputPipe( hPipeInput, Ready )

        If res = 0 Then
            If Err.LastDllError = 233 Then
                MessageBox.Show("Pipe peek failed, other end closed, err= " & Err.LastDllError)
            Else
                MessageBox.Show("Pipe peek unknown error, err= " & Err.LastDllError)
            End If
            Exit Sub
        End If


        ' If ready, actually read the data and update the screen.
        
        If Ready = 1 Then

            ' Read the data.

            res = VbCustomReadInputPipe( hPipeInput, BinData )

            If res = 0 Then
                If Err.LastDllError = 233 Then
                    MessageBox.Show("Pipe read failed, other end closed, err= " & Err.LastDllError)
                Else
                    MessageBox.Show("Pipe read error, err= " & Err.LastDllError)
                End If
                Exit Sub
            End If


            ' Update the values and refresh the screen.

            SampleLab.Text = "Sample #" & Format(BinData.Sample)

            Data0Lab.Text = Format(BinData.Analog0, "000000000")
            Data1Lab.Text = Format(BinData.Analog1, "000000000")
            Data2Lab.Text = Format(BinData.Analog2, "000000000")
            Data3Lab.Text = Format(BinData.Analog3, "000000000")
            Data4Lab.Text = Format(BinData.Analog4, "000000000")
            Data5Lab.Text = Format(BinData.Analog5, "000000000")
            Data6Lab.Text = Format(BinData.Analog6, "000000000")
            Data7Lab.Text = Format(BinData.Analog7, "000000000")
        
        End If


        ' Restart timer to get next point.

        Timer1.Start()

    End Sub

End Class

